==> aws-cdk.aws-synthetics-1.113.0.tar.gz: package/lib/synthetics-canned-metrics.generated.d.ts <==
export declare class CloudWatchSyntheticsMetrics {
    static _2XxSum(dimensions: {
        CanaryName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            CanaryName: string;
        };
        statistic: string;
    };
    static _4XxSum(dimensions: {
        CanaryName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            CanaryName: string;
        };
        statistic: string;
    };
    static _5XxSum(dimensions: {
        CanaryName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            CanaryName: string;
        };
        statistic: string;
    };
    static durationAverage(dimensions: {
        CanaryName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            CanaryName: string;
        };
        statistic: string;
    };
    static failedSum(dimensions: {
        CanaryName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            CanaryName: string;
        };
        statistic: string;
    };
    static failedRequestsSum(dimensions: {
        CanaryName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            CanaryName: string;
        };
        statistic: string;
    };
    static successPercentAverage(dimensions: {
        CanaryName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            CanaryName: string;
        };
        statistic: string;
    };
}

==> aws-cdk.aws-synthetics-1.133.0.tar.gz: package/lib/synthetics-canned-metrics.generated.d.ts <==
export declare class CloudWatchSyntheticsMetrics {
    static _2XxSum(dimensions: {
        CanaryName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            CanaryName: string;
        };
        statistic: string;
    };
    static _4XxSum(dimensions: {
        CanaryName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            CanaryName: string;
        };
        statistic: string;
    };
    static _5XxSum(dimensions: {
        CanaryName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            CanaryName: string;
        };
        statistic: string;
    };
    static durationAverage(dimensions: {
        CanaryName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            CanaryName: string;
        };
        statistic: string;
    };
    static failedSum(dimensions: {
        CanaryName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            CanaryName: string;
        };
        statistic: string;
    };
    static failedRequestsSum(dimensions: {
        CanaryName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            CanaryName: string;
        };
        statistic: string;
    };
    static successPercentAverage(dimensions: {
        CanaryName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            CanaryName: string;
        };
        statistic: string;
    };
}
